@@ -15,7 +15,7 @@ from .jobs import ListJobs, ListResources, ListJobArtifacts, ListJobLogs, GetJob
 from .machine_types import ListMachineTypes
 from .machines import CheckMachineAvailability, CreateMachine, CreateResource, StartMachine, StopMachine, \
     RestartMachine, GetMachine, UpdateMachine, GetMachineUtilization
-from .models import DeleteModel, ListModels, UploadModel, GetModel, ListModelFiles
+from .models import DeleteModel, ListModels, UploadModel, GetModel, ListModelFiles, CreateModel
 from .notebooks import CreateNotebook, DeleteNotebook, GetNotebook, ListNotebooks, GetNotebookMetrics, ListNotebookMetrics, \
     StreamNotebookMetrics, StopNotebook, StartNotebook, ForkNotebook, ListNotebookArtifacts, ListNotebookLogs
 from .projects import CreateProject, ListProjects, DeleteProject, GetProject
