@@ -5,11 +5,7 @@ from gradient.cli.cli import cli
 from gradient.cli.common import ClickGroup, api_key_option
 from gradient.commands import datasets as commands
 from gradient.cli import common
-from gradient.cli.jobs import get_workspace_handler
-from gradient.cli.common import (
-    api_key_option, del_if_value_is_none, ClickGroup, jsonify_dicts,
-    validate_comma_split_option,
-)
+from gradient.cli.common import api_key_option, ClickGroup
 
 EXAMPLE_ID = 'dsr8k5qzn401lb5'
 EXAMPLE_VERSION = 'klfoyy9'
@@ -37,11 +33,14 @@ def validate_dataset_id(dataset_ref, ref_type=None):
 
     dataset_id, _, ref = dataset_ref.partition(":")
     if not dataset_id:
-        raise click.UsageError("The '--id' option is missing the dataset ID (ex: {}})".format(full_part))
+        raise click.UsageError(
+            "The '--id' option is missing the dataset ID (ex: {}})".format(full_part))
     if ref_type and not ref:
-        raise click.UsageError("The '--id' option is missing the {} (ex: {})".format(ref_type, full_part))
+        raise click.UsageError(
+            "The '--id' option is missing the {} (ex: {})".format(ref_type, full_part))
     elif not ref_type and ref:
-        raise click.UsageError("The '--id' option should not have a version/tag (ex: {})".format(full_part))
+        raise click.UsageError(
+            "The '--id' option should not have a version/tag (ex: {})".format(full_part))
 
 
 @cli.group("datasets", help="Manage datasets", cls=ClickGroup)
@@ -149,65 +148,6 @@ def update_dataset(
         description=description,
     )
 
-@datasets.command("import", help="Import dataset")
-@click.option(
-    "--clusterId",
-    "cluster_id",
-    help="Cluster ID",
-    cls=common.GradientOption,
-    required=True,
-)
-@click.option(
-    "--machineType",
-    "machine_type",
-    help="Virtual machine type",
-    cls=common.GradientOption,
-    required=True,
-)
-@click.option(
-    "--datasetId",
-    "dataset_id",
-    help="Dataset ID",
-    cls=common.GradientOption,
-    required=True,
-)
-@click.option(
-    "--s3Url",
-    "s3_url",
-    help="S3 URL https://s3-us-east-1.amazonaws.com/bucket/path",
-    cls=common.GradientOption,
-)
-@click.option(
-    "--httpUrl",
-    "http_url",
-    help="HTTP/S URL https://data.something.org/all_my_data.zip}}",
-    cls=common.GradientOption,
-)
-@click.option(
-    "--httpAuth",
-    "http_auth",
-    help="Http Auth username:password",
-    cls=common.GradientOption,
-)
-@click.option(
-    "--s3AccessKey",
-    "access_key",
-    help="S3 access key",
-    cls=common.GradientOption,
-)
-@click.option(
-    "--s3SecretKey",
-    "secret_key",
-    help="S3 secret key",
-    cls=common.GradientOption,
-)
-@api_key_option
-@common.options_file
-def import_dataset(cluster_id, machine_type, dataset_id, s3_url, http_url, http_auth, access_key, secret_key, api_key, options_file):
-    validate_dataset_id(dataset_id)
-    
-    command = commands.ImportDatasetCommand(api_key=api_key, workspace_handler=get_workspace_handler())
-    command.execute(cluster_id, machine_type, dataset_id, s3_url, http_url, http_auth, access_key, secret_key)
 
 @datasets.command("delete", help="Delete dataset")
 @click.option(
@@ -370,7 +310,8 @@ def create_dataset_version(
 ):
     validate_dataset_id(dataset_id)
     command = commands.CreateDatasetVersionCommand(api_key=api_key)
-    command.execute(dataset_id=dataset_id, message=message, source_paths=source_paths)
+    command.execute(dataset_id=dataset_id, message=message,
+                    source_paths=source_paths)
 
 
 @dataset_versions.command("update", help="Update dataset version")
@@ -467,7 +408,8 @@ def dataset_version_files():
 def list_dataset_files(api_key, dataset_version_id, path, recursive, options_file):
     validate_dataset_id(dataset_version_id, ref_type='version')
     command = commands.ListDatasetFilesCommand(api_key=api_key)
-    execute_list(command, dataset_version_id=dataset_version_id, path=path, recursive=recursive)
+    execute_list(command, dataset_version_id=dataset_version_id,
+                 path=path, recursive=recursive)
 
 
 @dataset_version_files.command("get", help="Get files")
@@ -497,7 +439,8 @@ def list_dataset_files(api_key, dataset_version_id, path, recursive, options_fil
 def get_dataset_files(api_key, dataset_version_id, source_paths, target_path, options_file):
     validate_dataset_id(dataset_version_id, ref_type='version')
     command = commands.GetDatasetFilesCommand(api_key=api_key)
-    command.execute(dataset_version_id=dataset_version_id, source_paths=source_paths, target_path=target_path)
+    command.execute(dataset_version_id=dataset_version_id,
+                    source_paths=source_paths, target_path=target_path)
 
 
 @dataset_version_files.command("put", help="Put files")
@@ -527,7 +470,8 @@ def get_dataset_files(api_key, dataset_version_id, source_paths, target_path, op
 def put_dataset_files(api_key, dataset_version_id, source_paths, target_path, options_file):
     validate_dataset_id(dataset_version_id, ref_type='version')
     command = commands.PutDatasetFilesCommand(api_key=api_key)
-    command.execute(dataset_version_id=dataset_version_id, source_paths=source_paths, target_path=target_path)
+    command.execute(dataset_version_id=dataset_version_id,
+                    source_paths=source_paths, target_path=target_path)
 
 
 @dataset_version_files.command("delete", help="Delete files")
@@ -550,4 +494,5 @@ def put_dataset_files(api_key, dataset_version_id, source_paths, target_path, op
 def delete_dataset_files(api_key, dataset_version_id, paths, options_file):
     validate_dataset_id(dataset_version_id, ref_type='version')
     command = commands.DeleteDatasetFilesCommand(api_key=api_key)
-    command.execute(dataset_version_id=dataset_version_id, paths=paths or ['/'])
+    command.execute(dataset_version_id=dataset_version_id,
+                    paths=paths or ['/'])
